==> wordpress-2.1.1-da_DK.tar.gz: wordpress/wp-includes/js/tinymce/langs/da_dk.js <==
﻿// da_DK lang variables

tinyMCE.addToLang('',{
bold_desc : 'Fed (Ctrl+B)',
italic_desc : 'Kursiv (Ctrl+I)',
underline_desc : 'Understregning (Ctrl+U)',
striketrough_desc : 'Gennemstregning',
justifyleft_desc : 'Venstrejusteret',
justifycenter_desc : 'Centreret',
justifyright_desc : 'Højrejusteret',
justifyfull_desc : 'Lige margener',
bullist_desc : 'Punktopstilling',
numlist_desc : 'Nummeropstilling',
outdent_desc : 'Formindsk indrykning',
undo_desc : 'Fortryd (Ctrl+Z)',
redo_desc : 'Gendan (Ctrl+Y)',
link_desc : 'Indsæt/Rediger link',
unlink_desc : 'Slet link',
image_desc : 'Indsæt/Rediger billede',
cleanup_desc : 'Rengør dårlig kode',
focus_alert : 'Et editor-element skal være markeret for at bruge den kommando.',
edit_confirm : 'Vil du bruge WYSIWYG i dette tekstområde?',
insert_link_title : 'Indsæt/Rediger link',
insert : 'Indsæt',
update : 'Opdater',
cancel : 'Annuller',
insert_link_url : 'Link URL',
insert_link_target : 'Target',
insert_link_target_same : 'Åbn link i samme vindue',
insert_link_target_blank : 'Åbn link i et nyt vindue',
insert_image_title : 'Indsæt/Rediger billede',
insert_image_src : 'Billede-URL',
insert_image_alt : 'Billedbeskrivelse',
help_desc : 'Hjælp',
bold_img : "bold.gif",
italic_img : "italic.gif",
underline_img : "underline.gif",
clipboard_msg : 'Kopier/Klip/Sæt ind kan ikke bruges i Mozilla og Firefox.\nVil du have flere informationer om det?',
popup_blocked : 'Vi har lagt mærke til, at din popup-blocker har lukket et vindue, der fortæller om programmets funktioner. Du bliver nødt til at slå popup blocking fra på denne side, for at få fuldt udbytte af værktøjet.'
});

==> wordpress-2.3.1-da_DK.tar.gz: wordpress/wp-includes/js/tinymce/langs/da_dk.js <==
﻿// da_DK lang variables

tinyMCE.addToLang('',{
bold_desc : 'Fed (Ctrl+B)',
italic_desc : 'Kursiv (Ctrl+I)',
underline_desc : 'Understregning (Ctrl+U)',
striketrough_desc : 'Gennemstregning',
justifyleft_desc : 'Venstrejusteret',
justifycenter_desc : 'Centreret',
justifyright_desc : 'Højrejusteret',
justifyfull_desc : 'Lige margener',
bullist_desc : 'Punktopstilling',
numlist_desc : 'Nummeropstilling',
outdent_desc : 'Formindsk indrykning',
undo_desc : 'Fortryd (Ctrl+Z)',
redo_desc : 'Gendan (Ctrl+Y)',
link_desc : 'Indsæt/Rediger link',
unlink_desc : 'Slet link',
image_desc : 'Indsæt/Rediger billede',
cleanup_desc : 'Rengør dårlig kode',
focus_alert : 'Et editor-element skal være markeret for at bruge den kommando.',
edit_confirm : 'Vil du bruge WYSIWYG i dette tekstområde?',
insert_link_title : 'Indsæt/Rediger link',
insert : 'Indsæt',
update : 'Opdater',
cancel : 'Annuller',
insert_link_url : 'Link URL',
insert_link_target : 'Target',
insert_link_target_same : 'Åbn link i samme vindue',
insert_link_target_blank : 'Åbn link i et nyt vindue',
insert_image_title : 'Indsæt/Rediger billede',
insert_image_src : 'Billede-URL',
insert_image_alt : 'Billedbeskrivelse',
help_desc : 'Hj&aelig;lp',
bold_img : "bold.gif",
italic_img : "italic.gif",
underline_img : "underline.gif",
clipboard_msg : 'Kopier/Klip/Sæt ind kan ikke bruges i Mozilla og Firefox.\nVil du have flere informationer om det?',
popup_blocked : 'Vi har lagt mærke til, at din popup-blocker har lukket et vindue, der fortæller om programmets funktioner. Du bliver nødt til at slå popup blocking fra på denne side, for at få fuldt udbytte af værktøjet.'
});
